import { Duration, RemovalPolicy } from 'aws-cdk-lib';
import { IRole, Role } from 'aws-cdk-lib/aws-iam';
import { IFunction } from 'aws-cdk-lib/aws-lambda';
import { ILogGroup, RetentionDays } from 'aws-cdk-lib/aws-logs';
import { IStateMachine } from 'aws-cdk-lib/aws-stepfunctions';
import { Construct } from 'constructs';
/**
 * The interface representing the environment custom authorizer workflow.
 */
export interface AuthorizerEnvironmentWorflow {
    /**
     * The state machine that orchestrates the workflow.
     */
    readonly stateMachine: IStateMachine;
    /**
     * The IAM Role used by the State Machine
     */
    readonly stateMachineRole: IRole;
    /**
     * The log group where the state machine logs are stored.
     */
    readonly stateMachineLogGroup: ILogGroup;
}
/**
 * Setups the environment custom authorizer workflow.
 * This function creates the necessary grants for the central account to invoke the lambda function and assume the role.
 * @param scope The scope of the resources created
 * @param authorizerName The name of the authorizer
 * @param grantFunction The lambda function creating the grants
 * @param centralAccount The central account ID hosting the central authorizer workflow @default - The same account is used
 * @param stateMachineRole The role used by the Step Functions state machine @default - A new role is created
 * @param workflowTimeout The timeout for the state machine workflow. @default - 5 minutes
 * @param logRetention The retention period for the created logs. @default - 1 week
 * @returns The created AuthorizerEnvironmentWorflow
 */
export declare function authorizerEnvironmentWorkflowSetup(scope: Construct, authorizerName: string, grantFunction: IFunction, stateMachineRole?: Role, centralAccount?: string, workflowTimeout?: Duration, logRetention?: RetentionDays, removalPolicy?: RemovalPolicy): AuthorizerEnvironmentWorflow;
