import { CfnSubscriptionTarget } from 'aws-cdk-lib/aws-datazone';
import { IRole } from 'aws-cdk-lib/aws-iam';
import { Construct } from 'constructs';
import { CustomAssetType } from './datazone-custom-asset-type-factory';
import { DataZoneFormType } from './datazone-custom-asset-type-props';
export declare class DataZoneHelpers {
    /**
     * Build a Smithy model string from model fields.
     * @param formType The form type containing the model fields.
     * @returns The Smithy model string.
     */
    static buildModelString(formType: DataZoneFormType): string | undefined;
    /**
     * Creates a DataZone subscription target for a custom asset type.
     * Subscription targets are used to automatically add asset to environments when a custom asset is subscribed by a project.
     * @param scope The scope of the construct.
     * @param id The id of the construct.
     * @param customAssetType The custom asset type that can be added to the environment.
     * @param name The name of the subscription target.
     * @param provider The provider of the subscription target.
     * @param environmentId The DataZone environment identifier.
     * @param authorizedPrincipals The authorized principals to be granted when assets are subscribed.
     * @param manageAccessRole The IAM role creating the subscription target.
     * @returns The DataZone subscription target.
     */
    static createSubscriptionTarget(scope: Construct, id: string, customAssetType: CustomAssetType, name: string, provider: string, environmentId: string, authorizedPrincipals: IRole[], manageAccessRole: IRole): CfnSubscriptionTarget;
    private static readonly VALID_SMITHY_TYPES;
    /**
     * Check if a type is a valid smithy type.
     * @param type The smithy type to check.
     * @returns True if the type is a valid smithy type, false otherwise.
     */
    private static isValidSmithyType;
}
